Module executor

Module executor 

Structs

GenericExecutor
Helper for writing general kernel implementations with geometry
WkbBytesFactory
A GeometryFactory whose geometry type are raw WKB bytes
WkbGeometryFactory
A GeometryFactory whose geometry type is Wkb

Traits

GeometryFactory
Factory object to help the GenericExecutor iterate over various concrete geometry objects
IterGeo
Trait for iterating over a container type as geometry scalars

Type Aliases

WkbBytesExecutor
Alias for an executor that iterates over geometries in their raw Wkb bytes.
WkbExecutor
Alias for an executor that iterates over geometries as Wkb