WkbBytesExecutor

Type Alias WkbBytesExecutor 

pub type WkbBytesExecutor<'a, 'b> = GenericExecutor<'a, 'b, WkbBytesFactory, WkbBytesFactory>;
Alias for an executor that iterates over geometries in their raw Wkb bytes.

This GenericExecutor implementation provides more optimization opportunities, but it requires additional manual processing of the raw Wkb bytes compared to the WkbExecutor.

Aliased Type

pub struct WkbBytesExecutor<'a, 'b> {
    pub arg_types: &'a [SedonaType],
    pub args: &'b [ColumnarValue],
    /* private fields */
}

Fields

arg_types: &'a [SedonaType]args: &'b [ColumnarValue]