pub struct WkbBytesFactory {}Expand description
A GeometryFactory whose geometry type are raw WKB bytes
Using this geometry factory iterates over items as references to the raw underlying bytes, which is useful for writing optimized kernels that do not need the full buffer to be validated and/or parsed.