pub struct WkbGeometryFactory {}Expand description
A GeometryFactory whose geometry type is Wkb
Using this geometry factory iterates over items as references to Wkb objects (which are the fastest objects when iterating over WKB input that implement geo-traits).